% Matlab Init                                             :noexport:ignore:

current_dir='/home/thomas/MEGA/These/meas/instrumentation/';
%% Go to current Directory
cd(current_dir);

%% Clear Workspace and Close figures
clear; close all; clc;

%% Intialize Laplace variable
s = zpk('s');

%% Initialize ans with org-babel
ans = 0;

% Load data
% We load the data of the z axis of two geophones.

data = load('mat/data_018.mat', 'data'); data = data.data;

% Transfer function of the LPF
% We compute the transfer function from the signal without the LPF to the signal measured with the LPF.

dt = data(2, 3)-data(1, 3);

Fs = 1/dt; % [Hz]

win = hanning(ceil(10*Fs));

[Glpf, f] = tfestimate(data(:, 2), data(:, 1), win, [], [], Fs);



% We compare this transfer function with a transfer function corresponding to an ideal first order LPF with a cut-off frequency of $1000rad/s$.
% We obtain the result on figure [[fig:Glpf_bode]].

Gth = 1/(1+s/1000)

figure;
ax1 = subplot(2, 1, 1);
hold on;
plot(f, abs(Glpf));
plot(f, abs(squeeze(freqresp(Gth, f, 'Hz'))));
hold off;
set(gca, 'xscale', 'log'); set(gca, 'yscale', 'log');
set(gca, 'XTickLabel',[]);
ylabel('Magnitude');

ax2 = subplot(2, 1, 2);
hold on;
plot(f, mod(180+180/pi*phase(Glpf), 360)-180);
plot(f, 180/pi*unwrap(angle(squeeze(freqresp(Gth, f, 'Hz')))));
hold off;
set(gca, 'xscale', 'log');
ylim([-180, 180]);
yticks([-180, -90, 0, 90, 180]);
xlabel('Frequency [Hz]'); ylabel('Phase');

linkaxes([ax1,ax2],'x');
xlim([1, 500]);

% Load data
% We load the data of the z axis of two geophones.

data = load('mat/data_019.mat', 'data'); data = data.data;

% Transfer function of the LPF
% We compute the transfer function from the signal without the LPF to the signal measured with the LPF.

dt = data(2, 3)-data(1, 3);

Fs = 1/dt; % [Hz]

win = hanning(ceil(10*Fs));

[Glpf, f] = tfestimate(data(:, 2), data(:, 1), win, [], [], Fs);



% We compare this transfer function with a transfer function corresponding to an ideal first order LPF with a cut-off frequency of $1060Hz$.
% We obtain the result on figure [[fig:Glpf_bode_bis]].

Gth = 1/(1+s/1060/2/pi);

figure;
ax1 = subplot(2, 1, 1);
hold on;
plot(f, abs(Glpf));
plot(f, abs(squeeze(freqresp(Gth, f, 'Hz'))));
hold off;
set(gca, 'xscale', 'log'); set(gca, 'yscale', 'log');
set(gca, 'XTickLabel',[]);
ylabel('Magnitude');

ax2 = subplot(2, 1, 2);
hold on;
plot(f, mod(180+180/pi*phase(Glpf), 360)-180);
plot(f, 180/pi*unwrap(angle(squeeze(freqresp(Gth, f, 'Hz')))));
hold off;
set(gca, 'xscale', 'log');
ylim([-180, 180]);
yticks([-180, -90, 0, 90, 180]);
xlabel('Frequency [Hz]'); ylabel('Phase');

linkaxes([ax1,ax2],'x');
xlim([1, 500]);
